@@ -37,8 +37,10 @@ class Gherkin:
     
     def get_backgroud_steps(self):
         match = re.search("Background:(.*?)\n\n", self.data, flags=re.DOTALL)
-        scenario = Scenario(match.group(1))
-        return scenario.get_steps()
+        if match is not None:
+            return Scenario(match.group(1))
+        else:
+            return None
     
 class Scenario:
     def __init__(self, scenario_text):
@@ -46,7 +48,10 @@ class Scenario:
         
     def get_name(self):
         match = re.search("Scenario( Outline)?: (.*)\n", self.data)
-        return match.group(2)
+        if match is not None:
+            return match.group(2)
+        else:
+            return "Background"
     
     def is_outline(self):
         match = re.search("Scenario Outline:", self.data)
@@ -82,9 +87,9 @@ class Scenario:
         if self.is_outline():
             out += "\n\nExamples:\n"
             examples = self.get_examples()
-            out += "| "
+            out += "|"
             for h in examples[0].keys():
-                out += "{} |".format(h)
+                out += " {} |".format(h)
                 
             for example in examples:
                 out += "\n|"
